@@ -53,7 +53,7 @@ G_BEGIN_DECLS
 #endif /* !G_ENABLE_DEBUG */
 
 
-/* VOID:INT,INT (/usr/src/ports/eom/eom-1.10.3-1.i686/src/eom-1.10.3/cut-n-paste/toolbar-editor/eggmarshalers.list:1) */
+/* VOID:INT,INT (/usr/src/ports/eom/eom-1.18.1-1.x86_64/src/eom-1.18.1/cut-n-paste/toolbar-editor/eggmarshalers.list:1) */
 extern void _egg_marshal_VOID__INT_INT (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
@@ -72,9 +72,9 @@ _egg_marshal_VOID__INT_INT (GClosure     *closure,
                                               gint         arg_1,
                                               gint         arg_2,
                                               gpointer     data2);
-  register GMarshalFunc_VOID__INT_INT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__INT_INT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
