@@ -53,7 +53,7 @@ G_BEGIN_DECLS
 #endif /* !G_ENABLE_DEBUG */
 
 
-/* VOID:INT,INT (/usr/src/ports/eom/eom-1.10.3-1.x86_64/src/eom-1.10.3/src/eom-marshal.list:1) */
+/* VOID:INT,INT (/usr/src/ports/eom/eom-1.18.1-1.x86_64/src/eom-1.18.1/src/eom-marshal.list:1) */
 extern void eom_marshal_VOID__INT_INT (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
@@ -72,9 +72,9 @@ eom_marshal_VOID__INT_INT (GClosure     *closure,
                                               gint         arg_1,
                                               gint         arg_2,
                                               gpointer     data2);
-  register GMarshalFunc_VOID__INT_INT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__INT_INT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -96,7 +96,7 @@ eom_marshal_VOID__INT_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:DOUBLE (/usr/src/ports/eom/eom-1.10.3-1.x86_64/src/eom-1.10.3/src/eom-marshal.list:2) */
+/* VOID:DOUBLE (/usr/src/ports/eom/eom-1.18.1-1.x86_64/src/eom-1.18.1/src/eom-marshal.list:2) */
 #define eom_marshal_VOID__DOUBLE	g_cclosure_marshal_VOID__DOUBLE
 
 G_END_DECLS
